﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.IO;
using System.Runtime.CompilerServices;
using System.Threading.Tasks;
using Wisej.Core;
using Wisej.Design;

namespace Wisej.Web.Ext.Timeline
{
    /// <summary>
    /// The Tineline control: <see href="https://github.com/ka215/jquery.timeline"/>.
    /// </summary>
    [ToolboxItem(true)]
    [ToolboxBitmap(typeof(Timeline))]
    [ApiCategory("jQueryTimeline")]
    public class Timeline : Widget
    {

        public Timeline()
        {
        }

        #region Events


        #endregion

        #region Properties

        /// <summary>
		/// Overridden to return our list of script resources.
		/// </summary>
		[Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public override List<Package> Packages
        {
            // disable inlining or we lose the calling assembly in GetResourceString().
            [MethodImpl(MethodImplOptions.NoInlining)]
            get
            {
                if (base.Packages.Count == 0)
                {
                    // initialize the loader with the required libraries.

                    base.Packages.AddRange(new Package[] {
                        new Package() {
                            Name = "jquery.js",
                            Source = GetResourceURL("Wisej.Web.Ext.Timeline.JavaScript.jquery.min.js")
                        },
                        new Package() {
                            Name = "timeline.js",
                            Source = GetResourceURL("Wisej.Web.Ext.Timeline.JavaScript.jquery.timeline.min.js")
                        },
                        new Package() {
                            Name = "timeline.css",
                            Source = GetResourceURL("Wisej.Web.Ext.Timeline.JavaScript.jquery.timeline.min.css")
                        }
                    });
                }

                return base.Packages;
            }
        }



        /// <summary>
        /// Overridden to create our initialization script.
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public override string InitScript
        {
            get { return BuildInitScript(); }
            set { }
        }

        // disable inlining or we lose the calling assembly in GetResourceString().
        [MethodImpl(MethodImplOptions.NoInlining)]
        private string BuildInitScript()
        {
            dynamic options = new DynamicObject();
            string script = GetResourceString("Wisej.Web.Ext.Timeline.JavaScript.startup.js");

            script = script.Replace("$options", options.ToString());

            return script;
        }



        #endregion

    }
}
